@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997, 1998, 1999, 2002, 2003, 2004 Free Software
+ * Copyright (C) 1997, 1998, 1999, 2002, 2003, 2004, 2005 Free Software
  * Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -1086,6 +1086,11 @@ gdk_event_message (GdkEvent *event)
 
 
 /* As per Gtk 2.0, made available in Gtk 1.2. */
+#if 0
+/* This implementation is bad because gdk_event_copy does a gdk_window_ref
+   on the window field, and that's invalid for a window of NULL.
+   gdk_event_free can cope with a NULL window, if such an event could be
+   created.  But let's not worry about event object creation for now.  */
 GdkEvent *
 gdk_event_new (GdkEventType type)
 {
@@ -1094,6 +1099,7 @@ gdk_event_new (GdkEventType type)
   event.any.type = type;
   return gdk_event_copy (&event);
 }
+#endif
 
 
 /* Doesn't work. */
