@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 1997, 1998, 1999, 2000, 2002, 2003, 2004 Free Software
- * Foundation, Inc.
+ * Copyright (C) 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005 Free
+ * Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -401,7 +401,7 @@ static struct sgtk_protshell *global_protects;
 void
 sgtk_unprotect (sgtk_protshell *prot)
 {
-  if (*prot->prevp = prot->next)
+  if ((*prot->prevp = prot->next))
     prot->next->prevp = prot->prevp;
   g_chunk_free (prot, sgtk_protshell_chunk);
 }
@@ -502,7 +502,7 @@ sgtk_protect (SCM protector, SCM obj)
   else
     prevp = &global_protects;
   
-  if (prot->next = *prevp)
+  if ((prot->next = *prevp))
 	prot->next->prevp = &prot->next;
   *prevp = prot;
   prot->prevp = prevp;
@@ -569,7 +569,7 @@ gtkobj_free (SCM obj)
 
   forget_proxy (proxy->obj);
   gtk_object_unref (proxy->obj);
-  if (*proxy->prevp = proxy->next) proxy->next->prevp = proxy->prevp;
+  if ((*proxy->prevp = proxy->next)) proxy->next->prevp = proxy->prevp;
 
   assert (proxy->protects && proxy->protects->object == obj);
   sgtk_move_prots_to_global (proxy->protects->next);
@@ -754,8 +754,14 @@ SCM sgtk_flags_symbol_protector = SCM_BOOL_F;
 static int
 sgtk_flags_comp (const void *first, const void *second)
 {
-  return (SCM_UNPACK (((sgtk_enum_literal *) first)->symbol)
-	  - SCM_UNPACK (((sgtk_enum_literal *) second)->symbol));
+  if (SCM_UNPACK (((sgtk_enum_literal *) first)->symbol)
+      > SCM_UNPACK (((sgtk_enum_literal *) second)->symbol))
+    return 1;
+  else if (SCM_UNPACK (((sgtk_enum_literal *) first)->symbol)
+           < SCM_UNPACK (((sgtk_enum_literal *) second)->symbol))
+    return -1;
+  else
+    return 0;
 }
 
 void 
@@ -1500,7 +1506,7 @@ sgtk_composite_outconversion (SCM obj, SCM (*conversion)(SCM))
 SCM
 sgtk_slist2scm (GSList *list, SCM (*toscm)(void*))
 {
-  SCM res, *tail = &res;
+  SCM res = SCM_EOL, *tail = &res;
   while (list)
     {
       *tail = scm_cons (toscm (&list->data), *tail);
@@ -1582,7 +1588,7 @@ sgtk_slist_finish (GSList *list, SCM obj, SCM (*toscm)(void*))
 SCM
 sgtk_list2scm (GList *list, SCM (*toscm)(void*))
 {
-  SCM res, *tail = &res;
+  SCM res = SCM_EOL, *tail = &res;
   while (list)
     {
       *tail = scm_cons (toscm (&list->data), *tail);
@@ -1810,10 +1816,16 @@ sgtk_scm2raw (SCM obj, int pos, char* func)
       ret.count = SCM_STRING_LENGTH (obj);
       ret.raw = SCM_STRING_CHARS (obj);
       break;
+#ifdef SCM_UVECTOR_LENGTH /* gone in guile pre-1.8 */
+      /* FIXME: The uniform vector stuff has changed in guile pre-1.8, need
+         to go to the new interface to keep this working.  Or could just
+         remove it since the array-prototype style uniform stuff is
+         deprecated, and we never supported srfi-4 uniform arrays here.  */
     case scm_tc7_byvect:
       ret.count = SCM_UVECTOR_LENGTH (obj);
       ret.raw = (guchar*) SCM_VELTS (obj);
       break;
+#endif
     default:
       SCM_WRONG_TYPE_ARG (pos, obj);
     }
